@@ -1,7 +1,7 @@
 /*
  Authors 
  Yindeng, Jiang, jiangyindeng@gmail.com
- Martin Schlather, schlath@hsu-hh.de
+ Martin Schlather, martin.schlather@math.uni-goettingen.de
 
  Definition of correlation functions and derivatives (spectral measures, 
  tbm operators)
